---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

## Description

A clear and concise description of what the bug is.

## Condition and operation ("given" and "when" in test structure)

Steps to reproduce the behavior:

1. Prepare ...
2. Migrate with ...
3. See error

## Expected behavior ("then" in test structure)

A clear and concise description of what you expected to happen.

## Actual behavior

A clear and concise description of what you encountered to happen.
